# py-bot-starter

A Telegram bot framework to implement and deploy a bot in minutes

# Installation

Install the latest version of `py-bot-starter` with Pip:

```bash
pip install py-bot-starter
```

## Getting started with sample projects

You can find a collection of sample projects you can use to learn more about `py-bot-starter`'s features or as a
template for your own bot project. Check out [Sample Projects here](examples/README.md)

## Contributors ✨

Thanks goes to these wonderful people:

- [Diogo Kuiaski](https://github.com/diogokuiaski)

## License

[MIT License](LICENSE)